CreateWebhookSubscriptionRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

CreateWebhookSubscriptionRequest({required String callbackUrl, required String verificationToken, required WebhookOperation eventType, required ExtApiV2DataType dataType})
const
CreateWebhookSubscriptionRequest.fromJson(Map<String, dynamic> json)
factory

Properties

callbackUrl → String
final
dataType → ExtApiV2DataType
final
eventType → WebhookOperation
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verificationToken → String
final

Methods

copyWith({String? callbackUrl, String? verificationToken, WebhookOperation? eventType, ExtApiV2DataType? dataType}) → CreateWebhookSubscriptionRequest

Available on CreateWebhookSubscriptionRequest, provided by the $CreateWebhookSubscriptionRequestExtension extension

copyWithWrapped({Wrapped<String>? callbackUrl, Wrapped<String>? verificationToken, Wrapped<WebhookOperation>? eventType, Wrapped<ExtApiV2DataType>? dataType}) → CreateWebhookSubscriptionRequest

Available on CreateWebhookSubscriptionRequest, provided by the $CreateWebhookSubscriptionRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const CreateWebhookSubscriptionRequest Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(CreateWebhookSubscriptionRequest instance)