DailyResilienceModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

DailyResilienceModel({required String id, required DateTime day, required ResilienceContributors contributors, required LongTermResilienceLevel level})
const
DailyResilienceModel.fromJson(Map<String, dynamic> json)
factory

Properties

contributors → ResilienceContributors
final
day → DateTime
final
hashCode → int
The hash code for this object.
no setteroverride
id → String
final
level → LongTermResilienceLevel
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? id, DateTime? day, ResilienceContributors? contributors, LongTermResilienceLevel? level}) → DailyResilienceModel

Available on DailyResilienceModel, provided by the $DailyResilienceModelExtension extension

copyWithWrapped({Wrapped<String>? id, Wrapped<DateTime>? day, Wrapped<ResilienceContributors>? contributors, Wrapped<LongTermResilienceLevel>? level}) → DailyResilienceModel

Available on DailyResilienceModel, provided by the $DailyResilienceModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const DailyResilienceModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(DailyResilienceModel instance)