DailySleepModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

DailySleepModel({required String id, required SleepContributors contributors, required DateTime day, required dynamic score, required String timestamp})
const
DailySleepModel.fromJson(Map<String, dynamic> json)
factory

Properties

contributors → SleepContributors
final
day → DateTime
final
hashCode → int
The hash code for this object.
no setteroverride
id → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → dynamic
final
timestamp → String
final

Methods

copyWith({String? id, SleepContributors? contributors, DateTime? day, dynamic score, String? timestamp}) → DailySleepModel

Available on DailySleepModel, provided by the $DailySleepModelExtension extension

copyWithWrapped({Wrapped<String>? id, Wrapped<SleepContributors>? contributors, Wrapped<DateTime>? day, Wrapped? score, Wrapped<String>? timestamp}) → DailySleepModel

Available on DailySleepModel, provided by the $DailySleepModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const DailySleepModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(DailySleepModel instance)