DailySpO2AggregatedValuesModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

DailySpO2AggregatedValuesModel({required double average})
const
DailySpO2AggregatedValuesModel.fromJson(Map<String, dynamic> json)
factory

Properties

average → double
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? average}) → DailySpO2AggregatedValuesModel

Available on DailySpO2AggregatedValuesModel, provided by the $DailySpO2AggregatedValuesModelExtension extension

copyWithWrapped({Wrapped<double>? average}) → DailySpO2AggregatedValuesModel

Available on DailySpO2AggregatedValuesModel, provided by the $DailySpO2AggregatedValuesModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const DailySpO2AggregatedValuesModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(DailySpO2AggregatedValuesModel instance)