MultiDocumentResponseEnhancedTagModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

MultiDocumentResponseEnhancedTagModel({required List<EnhancedTagModel> data, required dynamic nextToken})
const
MultiDocumentResponseEnhancedTagModel.fromJson(Map<String, dynamic> json)
factory

Properties

data → List<EnhancedTagModel>
final
hashCode → int
The hash code for this object.
no setteroverride
nextToken → dynamic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<EnhancedTagModel>? data, dynamic nextToken}) → MultiDocumentResponseEnhancedTagModel

Available on MultiDocumentResponseEnhancedTagModel, provided by the $MultiDocumentResponseEnhancedTagModelExtension extension

copyWithWrapped({Wrapped<List<EnhancedTagModel>>? data, Wrapped? nextToken}) → MultiDocumentResponseEnhancedTagModel

Available on MultiDocumentResponseEnhancedTagModel, provided by the $MultiDocumentResponseEnhancedTagModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const MultiDocumentResponseEnhancedTagModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(MultiDocumentResponseEnhancedTagModel instance)