MultiDocumentResponseVO2MaxModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

MultiDocumentResponseVO2MaxModel({required List<VO2MaxModel> data, required dynamic nextToken})
const
MultiDocumentResponseVO2MaxModel.fromJson(Map<String, dynamic> json)
factory

Properties

data → List<VO2MaxModel>
final
hashCode → int
The hash code for this object.
no setteroverride
nextToken → dynamic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<VO2MaxModel>? data, dynamic nextToken}) → MultiDocumentResponseVO2MaxModel

Available on MultiDocumentResponseVO2MaxModel, provided by the $MultiDocumentResponseVO2MaxModelExtension extension

copyWithWrapped({Wrapped<List<VO2MaxModel>>? data, Wrapped? nextToken}) → MultiDocumentResponseVO2MaxModel

Available on MultiDocumentResponseVO2MaxModel, provided by the $MultiDocumentResponseVO2MaxModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const MultiDocumentResponseVO2MaxModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(MultiDocumentResponseVO2MaxModel instance)