RestModeEpisode class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

RestModeEpisode({required List<String> tags, required String timestamp})
const
RestModeEpisode.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<String>
final
timestamp → String
final

Methods

copyWith({List<String>? tags, String? timestamp}) → RestModeEpisode

Available on RestModeEpisode, provided by the $RestModeEpisodeExtension extension

copyWithWrapped({Wrapped<List<String>>? tags, Wrapped<String>? timestamp}) → RestModeEpisode

Available on RestModeEpisode, provided by the $RestModeEpisodeExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const RestModeEpisode Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(RestModeEpisode instance)