SampleModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

SampleModel({required double interval, required List<Object> items, required String timestamp})
const
SampleModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
interval → double
final
items → List<Object>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → String
final

Methods

copyWith({double? interval, List<Object>? items, String? timestamp}) → SampleModel

Available on SampleModel, provided by the $SampleModelExtension extension

copyWithWrapped({Wrapped<double>? interval, Wrapped<List<Object>>? items, Wrapped<String>? timestamp}) → SampleModel

Available on SampleModel, provided by the $SampleModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const SampleModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(SampleModel instance)