TagModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

TagModel({required String id, required DateTime day, required dynamic text, required DateTime timestamp, required List<String> tags})
const
TagModel.fromJson(Map<String, dynamic> json)
factory

Properties

day → DateTime
final
hashCode → int
The hash code for this object.
no setteroverride
id → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<String>
final
text → dynamic
final
timestamp → DateTime
final

Methods

copyWith({String? id, DateTime? day, dynamic text, DateTime? timestamp, List<String>? tags}) → TagModel

Available on TagModel, provided by the $TagModelExtension extension

copyWithWrapped({Wrapped<String>? id, Wrapped<DateTime>? day, Wrapped? text, Wrapped<DateTime>? timestamp, Wrapped<List<String>>? tags}) → TagModel

Available on TagModel, provided by the $TagModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const TagModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(TagModel instance)