ValidationError class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ValidationError({required List<Object> loc, required String msg, required String type})
const
ValidationError.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
loc → List<Object>
final
msg → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

copyWith({List<Object>? loc, String? msg, String? type}) → ValidationError

Available on ValidationError, provided by the $ValidationErrorExtension extension

copyWithWrapped({Wrapped<List<Object>>? loc, Wrapped<String>? msg, Wrapped<String>? type}) → ValidationError

Available on ValidationError, provided by the $ValidationErrorExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const ValidationError Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ValidationError instance)